import {Renderer} from "@k8slens/extensions";
import {Scanner} from "../trivy_operator/types";

export class Vulnerability {
    vulnerabilityID: string;
    title?: string;
    resource: string;
    installedVersion: string;
    fixedVersion?: string;
    severity: string;
    target: string;
    primaryLink: string;

    constructor(params: Vulnerability) {
        Object.entries(params).forEach(([key, value]) => {
            Object.assign(this, {[key]: value})
        });
    }

    getId() {
        return this.vulnerabilityID
    }

    getName() {
        return this.title
    }
}

export class ClusterVulnerabilityReport extends Renderer.K8sApi.KubeObject {
    static kind = "ClusterVulnerabilityReport"
    static namespaced = false
    static apiBase = "/apis/aquasecurity.github.io/v1alpha1/clustervulnerabilityreports"

    report: VulnerabilityReportData;

    getImageRef(): string {
        const {artifact, registry} = this.report
        let imageId
        if (artifact.tag && artifact.digest) {
            imageId = ":" + artifact.tag + "@" + artifact.digest
        }
        if (artifact.tag && !artifact.digest) {
            imageId = ":" + artifact.tag
        }
        if (artifact.digest && !artifact.tag) {
            imageId = "@" + artifact.digest
        }

        return registry.server + "/" + artifact.repository + imageId
    };
}

export class VulnerabilityReport extends Renderer.K8sApi.KubeObject {
    static kind = "VulnerabilityReport"
    static namespaced = true
    static apiBase = "/apis/aquasecurity.github.io/v1alpha1/vulnerabilityreports"

    report: VulnerabilityReportData;

    getImageRef(): string {
        const {artifact, registry} = this.report
        let imageId
        if (artifact.tag && artifact.digest) {
            imageId = ":" + artifact.tag + "@" + artifact.digest
        }
        if (artifact.tag && !artifact.digest) {
            imageId = ":" + artifact.tag
        }
        if (artifact.digest && !artifact.tag) {
            imageId = "@" + artifact.digest
        }

        return registry.server + "/" + artifact.repository + imageId
    };

}

export type VulnerabilitySummary = {
    criticalCount: number;
    highCount: number;
    lowCount: number;
    mediumCount: number;
    noneCount: number;
    unknownCount: number;
}

export type VulnerabilityReportData = {
    updateTimestamp: string;
    registry: {
        server: string;
    }
    artifact: {
        repository: string;
        tag?: string;
        digest?: string;
    }
    scanner: Scanner;
    summary: VulnerabilitySummary;
    vulnerabilities: Vulnerability[];
}
